@@ -239,9 +239,12 @@ esb.test = function (x, input = "dataframe", n_cases = NULL, n_controls = NULL,
   } else {
     for (i in 1:k) {
       x$power[i] = switch (measure,
-                           "SMD"= .power_d(n_cases = x$n_cases[i], n_controls = x$n_controls[i], true_d = true_value, se = x$se[i]),
-                           "SMC" = .power_d(n_cases = x$n_cases[i], n_controls = x$n_controls[i], true_d = true_value, se = x$se[i]),
-                           "Z" =  pwr::pwr.r.test(n = x$n_sample[i], r = .z_to_r(true_value), alternative = "two.sided")$power,
+                           "SMD"= .power_d(n_cases = x$n_cases[i], n_controls = x$n_controls[i],
+                                           true_d = true_value, se = x$se[i]),
+                           "SMC" = .power_d(n_cases = x$n_cases[i], n_controls = x$n_controls[i],
+                                            true_d = true_value, se = x$se[i]),
+                           "Z" =  pwr::pwr.r.test(n = x$n_sample[i], r = .z_to_r(true_value),
+                                                  alternative = "two.sided")$power,
                            "HR" = .power_hr(x[i, ], true_value),
                            "IRR" = .power_irr(x[i, ], true_value),
                            "OR" = .power_or(x[i, ], true_value),
