@@ -242,8 +242,8 @@ umbrella = function (x, method.var = "REML", mult.level = FALSE, r = 0.5, method
       ma_results = data.frame(value = coef, z, p.value, ci_lo, ci_up, pi_lo, pi_up)
       rownames(ma_results) = switch(as.character(measure),
                                 "SMD" = "Bias-corrected SMD",
-                                "Z" = "Standardized mean change",
-                                "SMC" = "SMC",
+                                "Z" = "Fisher's Z",
+                                "SMC" = "Standardized mean change",
                                 "OR" = "log (OR)",
                                 "RR" = "log (RR)",
                                 "IRR" = "log (IRR)",
